<!-- These are examples of badges you might want to add to your README:
     please update the URLs accordingly

[![Built Status](https://api.cirrus-ci.com/github/<USER>/mucklas.svg?branch=main)](https://cirrus-ci.com/github/<USER>/mucklas)
[![ReadTheDocs](https://readthedocs.org/projects/mucklas/badge/?version=latest)](https://mucklas.readthedocs.io/en/stable/)
[![Coveralls](https://img.shields.io/coveralls/github/<USER>/mucklas/main.svg)](https://coveralls.io/r/<USER>/mucklas)
[![PyPI-Server](https://img.shields.io/pypi/v/mucklas.svg)](https://pypi.org/project/mucklas/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/mucklas.svg)](https://anaconda.org/conda-forge/mucklas)
[![Monthly Downloads](https://pepy.tech/badge/mucklas/month)](https://pepy.tech/project/mucklas)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter)](https://twitter.com/mucklas)
-->

[![Project generated with PyScaffold](https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold)](https://pyscaffold.org/)

# mucklas

> A collection of useful (Python) functions and concepts. Something you can discover if you look closely - just
> like the fictional creatures of the same name in Sven Nordqvist's Swedish books 'Pettson och Findus'.

This is a collection that is organized in a way that makes it easy to discover and use the functions and concepts.
The collection can be installed as a dependency into projects.

## Installation

```bash
pip install mucklas
```

## Content

The collection is organized in modules. Each module contains a set of functions and concepts that are related to
each other and have a common theme. The modules are:

- [`mucklas.dataclasses`](docs/dataclasses.md): A collection of functions to work with dataclasses, e.g., for defining typed param
  objects
  to pass to functions.








<!-- pyscaffold-notes -->

## Note

This project has been set up using PyScaffold 4.6. For details and usage
information on PyScaffold see https://pyscaffold.org/.
